==> apache-shenyu-incubating-2.4.2-src.zip: apache-shenyu-incubating-2.4.2-src/shenyu-common/src/test/java/org/apache/shenyu/common/utils/VersionUtilsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.common.utils;

import org.junit.Test;

import static org.junit.Assert.assertNotNull;

/**
 * Test cases for VersionUtils.
 */
public final class VersionUtilsTest {

    @Test
    public void testFromDefaultVersion() {
        String version = VersionUtils.getVersion();
        assertNotNull(version);
    }
    
    @Test
    public void testFromImplementationVersion() throws ClassNotFoundException {
        String version = VersionUtils.getVersion(Class.forName("java.lang.String"), "2.0.2");
        assertNotNull(version);
    }
    
    @Test
    public void testFromCodeSource() throws ClassNotFoundException {
        String version = VersionUtils.getVersion(Class.forName("ch.qos.logback.classic.db.DBAppender"), "2.0.2");
        assertNotNull(version);
    }

}

==> apache-shenyu-incubating-2.4.3-src.zip: apache-shenyu-incubating-2.4.3-src/shenyu-common/src/test/java/org/apache/shenyu/common/utils/VersionUtilsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.common.utils;

import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertNotNull;

/**
 * Test cases for VersionUtils.
 */
public final class VersionUtilsTest {

    @Test
    public void testFromDefaultVersion() {
        String version = VersionUtils.getVersion();
        assertNotNull(version);
    }
    
    @Test
    public void testFromImplementationVersion() throws ClassNotFoundException {
        String version = VersionUtils.getVersion(Class.forName("java.lang.String"), "2.0.2");
        assertNotNull(version);
    }
    
    @Test
    public void testFromCodeSource() throws ClassNotFoundException {
        String version = VersionUtils.getVersion(Class.forName("ch.qos.logback.classic.db.DBAppender"), "2.0.2");
        assertNotNull(version);
    }

}
